ad_page_contract {
} {
    list_id:integer,notnull
    public_p:optional
    {users_read:multiple,optional ""}
    {users_admin:multiple,optional ""}
}

set package_id [ad_conn package_id]
set user_id [ad_conn user_id]

permission::require_permission -object_id $package_id -privilege mailing_list_admin
permission::require_permission -object_id $list_id -privilege admin

if {[exists_and_not_null public_p]} {
    # toggle public_p
    db_transaction {
	db_dml update_public_p {}

	set the_public_id [acs_magic_object the_public]
	if {$public_p == "t"} {
	    # grant all users read permissions -> public mailing list
	    db_exec_plsql grant_user_list_read_privilege {}
	} else {
	    # revoke read permission for all users -> private mailing list
	    db_exec_plsql revoke_user_list_read_privilege {}
	}
    }
} else {
    # set direct permissions
    set add_users [list]
    set remove_users [list]
    if {![empty_string_p $users_read]} {
	# we want to grant read permission to users
	template::util::list_to_lookup $users_read admin_ids
	set privilege read
    } else {
	# we want to grant admin permission to users
	template::util::list_to_lookup $users_admin admin_ids
	set privilege admin
    }

    # get all users who've got the mailing_list_admin permission,
    # but don't have the admin permission on the package
    # (since you can't revoke the read/admin list permissions from them)
    db_foreach get_all_mailing_list_admins {} {
	if {$permission_p == "f" && [info exists admin_ids($party_id)]} {
	    # doesn't have the permission right now, but user wants him to
	    lappend add_users $party_id
	}
	if {$permission_p == "t" && ![info exists admin_ids($party_id)]} {
	    # does have the permission right now, but user doesn't want him to
	    lappend remove_users $party_id
	}
    }

    db_transaction {
	# grant permission to users
	foreach users_id $add_users {
	    db_exec_plsql grant_user_list_privilege {}
	}

	# revoke permission from users
	foreach users_id $remove_users {
	    db_exec_plsql revoke_user_list_privilege {}
	}
    }
}

ad_returnredirect "list-permissions?[export_url_vars list_id]"
